==> RxKit-2.0.0-sources.jar: com/vondear/rxtool/RxConstants.java <==
package com.vondear.rxtool;

/**
 *
 * @author vondear
 * @date 2017/1/13
 */

public class RxConstants {
    //----------------------------------------------------常用链接- start ------------------------------------------------------------

    /**
     * RxTools的Github地址
     */
    public static final String URL_VONTOOLS = "https://github.com/vondear/RxTool";

    /**
     * 百度文字搜索
     */
    public static final String URL_BAIDU_SEARCH = "http://www.baidu.com/s?wd=";

    /**
     * ACFUN
     */
    public static final String URL_ACFUN = "http://www.acfun.tv/";

    public static final String URL_JPG_TO_FONT = "http://ku.cndesign.com/pic/";

    //===================================================常用链接== end ==============================================================
    public static final String URL_BORING_PICTURE = "http://jandan.net/?oxwlxojflwblxbsapi=jandan.get_pic_comments&page=";
    public static final String URL_PERI_PICTURE = "http://jandan.net/?oxwlxojflwblxbsapi=jandan.get_ooxx_comments&page=";
    public static final String URL_JOKE_MUSIC = "http://route.showapi.com/255-1?type=31&showapi_appid=20569&showapi_sign=0707a6bfb3e842fb8c8aa450012d9756&page=";
    public static final String SP_MADE_CODE = "MADE_CODE";
    //==========================================煎蛋 API end=========================================
    public static final String SP_SCAN_CODE = "SCAN_CODE";
    //微信统一下单接口
    public static final String WX_TOTAL_ORDER = "https://api.mch.weixin.qq.com/pay/unifiedorder";
    //------------------------------------------煎蛋 API start--------------------------------------
    public static String URL_JOKE = "http://ic.snssdk.com/neihan/stream/mix/v1/?" +
            "mpic=1&essence=1" +
            "&content_type=-102" +
            "&message_cursor=-1" +
            "&bd_Stringitude=113.369569" +
            "&bd_latitude=23.149678" +
            "&bd_city=%E5%B9%BF%E5%B7%9E%E5%B8%82" +
            "&am_Stringitude=113.367846" +
            "&am_latitude=23.149878" +
            "&am_city=%E5%B9%BF%E5%B7%9E%E5%B8%82" +
            "&am_loc_time=1465213692154&count=30" +
            "&min_time=1465213700&screen_width=720&iid=4512422578" +
            "&device_id=17215021497" +
            "&ac=wifi" +
            "&channel=NHSQH5AN" +
            "&aid=7" +
            "&app_name=joke_essay" +
            "&version_code=431" +
            "&device_platform=android" +
            "&ssmix=a" +
            "&device_type=6s+Plus" +
            "&os_api=19" +
            "&os_version=4.4.2" +
            "&uuid=864394108025091" +
            "&openudid=80FA5B208E050000" +
            "&manifest_version_code=431";


    //高德地图APP 包名
    public static final String GAODE_PACKAGE_NAME = "com.autonavi.minimap";
    //百度地图APP 包名
    public static final String BAIDU_PACKAGE_NAME = "com.baidu.BaiduMap";

}

==> RxKit-2.0.1-sources.jar: com/vondear/rxtool/RxConstants.java <==
package com.vondear.rxtool;

import java.text.DecimalFormat;

/**
 *
 * @author vondear
 * @date 2017/1/13
 */

public class RxConstants {
    //----------------------------------------------------常用链接- start ------------------------------------------------------------

    /**
     * RxTools的Github地址
     */
    public static final String URL_VONTOOLS = "https://github.com/vondear/RxTool";

    /**
     * 百度文字搜索
     */
    public static final String URL_BAIDU_SEARCH = "http://www.baidu.com/s?wd=";

    /**
     * ACFUN
     */
    public static final String URL_ACFUN = "http://www.acfun.tv/";

    public static final String URL_JPG_TO_FONT = "http://ku.cndesign.com/pic/";

    //===================================================常用链接== end ==============================================================
    public static final String URL_BORING_PICTURE = "http://jandan.net/?oxwlxojflwblxbsapi=jandan.get_pic_comments&page=";
    public static final String URL_PERI_PICTURE = "http://jandan.net/?oxwlxojflwblxbsapi=jandan.get_ooxx_comments&page=";
    public static final String URL_JOKE_MUSIC = "http://route.showapi.com/255-1?type=31&showapi_appid=20569&showapi_sign=0707a6bfb3e842fb8c8aa450012d9756&page=";
    public static final String SP_MADE_CODE = "MADE_CODE";
    //==========================================煎蛋 API end=========================================
    public static final String SP_SCAN_CODE = "SCAN_CODE";
    //微信统一下单接口
    public static final String WX_TOTAL_ORDER = "https://api.mch.weixin.qq.com/pay/unifiedorder";
    //------------------------------------------煎蛋 API start--------------------------------------
    public static String URL_JOKE = "http://ic.snssdk.com/neihan/stream/mix/v1/?" +
            "mpic=1&essence=1" +
            "&content_type=-102" +
            "&message_cursor=-1" +
            "&bd_Stringitude=113.369569" +
            "&bd_latitude=23.149678" +
            "&bd_city=%E5%B9%BF%E5%B7%9E%E5%B8%82" +
            "&am_Stringitude=113.367846" +
            "&am_latitude=23.149878" +
            "&am_city=%E5%B9%BF%E5%B7%9E%E5%B8%82" +
            "&am_loc_time=1465213692154&count=30" +
            "&min_time=1465213700&screen_width=720&iid=4512422578" +
            "&device_id=17215021497" +
            "&ac=wifi" +
            "&channel=NHSQH5AN" +
            "&aid=7" +
            "&app_name=joke_essay" +
            "&version_code=431" +
            "&device_platform=android" +
            "&ssmix=a" +
            "&device_type=6s+Plus" +
            "&os_api=19" +
            "&os_version=4.4.2" +
            "&uuid=864394108025091" +
            "&openudid=80FA5B208E050000" +
            "&manifest_version_code=431";


    //高德地图APP 包名
    public static final String GAODE_PACKAGE_NAME = "com.autonavi.minimap";
    //百度地图APP 包名
    public static final String BAIDU_PACKAGE_NAME = "com.baidu.BaiduMap";

    /**
     * 速度格式化
     */
    public static final DecimalFormat FORMAT_ONE = new DecimalFormat("#.#");
    /**
     * 距离格式化
     */
    public static final DecimalFormat FORMAT_TWO = new DecimalFormat("#.##");
    /**
     * 速度格式化
     */
    public static final DecimalFormat FORMAT_THREE = new DecimalFormat("#.###");

}
